@@ -60,7 +60,7 @@ $lang = array_merge($lang, array(
 	'DEFAULT_LANGUAGE'				=> 'Standardsprog',
 	'DEFAULT_STYLE'					=> 'Standardtypografi',
 	'DISABLE_BOARD'					=> 'Deaktiver boardet',
-	'DISABLE_BOARD_EXPLAIN'			=> 'Sætter boardet offline for brugere. Du kan vælge at indtaste en kort meddelelse, der skal vises i stedet (maksimalt 255 tegn).',
+	'DISABLE_BOARD_EXPLAIN'			=> 'Sætter boardet offline for brugere, undtaget administratorer og redaktører. Du kan vælge at indtaste en kort meddelelse, der skal vises i stedet (maksimalt 255 tegn).',
 	'OVERRIDE_STYLE'				=> 'Tilsidesæt brugeres valg af typografi',
 	'OVERRIDE_STYLE_EXPLAIN'		=> 'Erstatter brugeres valg af typografi med boardets standardtypografi.',
 	'SITE_DESC'						=> 'Boardbeskrivelse',
@@ -120,7 +120,7 @@ $lang = array_merge($lang, array(
 	'AVATAR_GALLERY_PATH'			=> 'Avatargallerimappens placering',
 	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Sti under din phpBB-rodmappe for forhåndsuploadede avatars, f.eks. <samp>images/avatars/gallery</samp>.',
 	'AVATAR_STORAGE_PATH'			=> 'Avatarmappens placering',
-	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Sti under din phpBB-rodmappe, f.eks. <samp>images/avatars/upload</samp>.',
+	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Sti under din phpBB-rodmappe, f.eks. <samp>images/avatars/upload</samp>.<br />Avatarer <strong>kan ikke</strong> uploades, hvis der ikke er skriveadgang til mappen.',
 	'MAX_AVATAR_SIZE'				=> 'Største dimensioner for avatar',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Bredde x højde i pixels.',
 	'MAX_FILESIZE'					=> 'Maksimal filstørrelse for avatar',
