@@ -4,7 +4,7 @@
 * common [Danish]
 *
 * @package language
-* @version $Id: common.php 292 2013-06-01 06:14:44Z jan_skovsgaard $
+* @version $Id: common.php 398 2014-05-08 18:02:50Z jan_skovsgaard $
 * @source file is copyright (c) 2005 phpBB Group
 * @modified and translated by Olympus DK Team
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
@@ -102,9 +102,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'	=> 'Den angivne fil blev kun delvist uploadet.',
 	'AVATAR_PHP_SIZE_NA'	=> 'Avatarens filstørrelse er for stor.<br />Den maksimale filstørrelse defineret i php.ini kunne ikke afgøres.',
 	'AVATAR_PHP_SIZE_OVERRUN'	=> 'Avatarens filstørrelse er for stor. Den maksimale uploadstørrelse er %1$d %2$s.<br />Bemærk at grænsen er defineret i php.ini filen, og ikke kan tilsidesættes.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'	=> 'Den angivne avatar kunne ikke uploades fordi forespørgslen udløb.',
 	'AVATAR_URL_INVALID'	=> 'Den angivne URL er ugyldig.',
 	'AVATAR_URL_NOT_FOUND'	=> 'Den angivne fil kunne ikke findes.',
-	'AVATAR_WRONG_FILESIZE'	=> 'Avatarens filstørrelse skal være mellem 0 og %1d %2s.',
+	'AVATAR_WRONG_FILESIZE'	=> 'Avatarens filstørrelse skal være mellem 0 og %1$d %2$s.',
 	'AVATAR_WRONG_SIZE'	=> 'Den indsendte avatar er %5$d pixels bred og %6$d pixels høj. Den skal være mindst %1$d pixels bred, %2$d pixels høj og maksimalt %3$d pixels bred og %4$d pixels høj.',
 
 	'BACK_TO_TOP'	=> 'Top',
@@ -355,6 +356,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'	=> 'Rediger',
 	'MODERATOR'	=> 'Redaktør',
 	'MODERATORS'	=> 'Redaktører',
+	'MODULE_NOT_ACCESS'				=> 'Modulet kunne ikke tilgås',
+	'MODULE_NOT_FIND'				=> 'Modulet %s findes ikke',
+	'MODULE_FILE_INCORRECT_CLASS'	=> 'Modulfilen %s indeholder ikke den korrekte class [%s]',
 	'MONTH'	=> 'Måned',
 	'MOVE'	=> 'Flyt',
 	'MSNM'	=> 'MSNM/WLM',
@@ -419,7 +423,7 @@ $lang = array_merge($lang, array(
 	'NO_USER'	=> 'Den valgte bruger findes ikke.',
 	'NO_USERS'	=> 'De valgte brugere findes ikke',
 	'NO_USER_SPECIFIED'			=> 'Der var ikke angivet et brugernavn.',
-	
+
 	// Nullar/Singular/Plural language entry. The key numbers define the number range in which a certain grammatical expression is valid.
 	'NUM_POSTS_IN_QUEUE'		=> array(
 		0										=> 'Ingen indlæg i kø',		// 0
@@ -538,19 +542,19 @@ $lang = array_merge($lang, array(
 	'SEARCH'	=> 'Søg',
 	'SEARCH_MINI'	=> 'Søg…',
 	'SEARCH_ADV'	=> 'Avanceret søgning',
-	'SEARCH_ADV_EXPLAIN'	=> 'Vis avancerede søgemuligheder',
+	'SEARCH_ADV_EXPLAIN'	=> 'Avancerede søgemuligheder',
 	'SEARCH_KEYWORDS'	=> 'Søg efter nøgleord',
 	'SEARCHING_FORUMS'	=> 'Søger fora',
-	'SEARCH_ACTIVE_TOPICS'	=> 'Vis aktive emner',
+	'SEARCH_ACTIVE_TOPICS'	=> 'Aktive emner',
 	'SEARCH_FOR'	=> 'Søg efter',
 	'SEARCH_FORUM'				=> 'Søg i dette forum...',
-	'SEARCH_NEW'	=> 'Vis nye indlæg',
+	'SEARCH_NEW'	=> 'Nye indlæg',
 	'SEARCH_POSTS_BY'			=> 'Søg indlæg af',
-	'SEARCH_SELF'	=> 'Vis dine indlæg',
+	'SEARCH_SELF'	=> 'Dine indlæg',
 	'SEARCH_TOPIC'				=> 'Søg i dette emne...',
-	'SEARCH_UNANSWERED'	=> 'Vis ubesvarede indlæg',
-	'SEARCH_UNREAD'			=> 'Vis ulæste indlæg',
-	'SEARCH_USER_POSTS'		=> 'Vis brugers indlæg',
+	'SEARCH_UNANSWERED'	=> 'Ubesvarede indlæg',
+	'SEARCH_UNREAD'			=> 'Ulæste indlæg',
+	'SEARCH_USER_POSTS'		=> 'Brugers indlæg',
 	'SECONDS'	=> 'sekunder',
 	'SELECT'	=> 'Vælg',
 	'SELECT_ALL_CODE'	=> 'Vælg alt',
@@ -665,7 +669,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> 'Tilmeldte brugere <strong>0</strong>',
 	'TRACKED_PHP_ERROR'	=> 'Sporede PHP-fejl: %s',
 
-	'UNABLE_GET_IMAGE_SIZE'	=> 'Det var ikke muligt at fastslå billedets dimensioner.',
+	'UNABLE_GET_IMAGE_SIZE'	=> 'Det var ikke muligt at fastslå billedets dimensioner. Kontroller venligst at den angivne URL er korrekt.',
 	'UNABLE_TO_DELIVER_FILE'=> 'Kunne ikke aflevere fil.',
 	'UNKNOWN_BROWSER'	=> 'Ukendt browser',
 	'UNMARK_ALL'	=> 'Fravælg alle',
